@@ -36,9 +36,12 @@
 
 #include "file-data.h"
 #include "file-utils.h"
+#include "glib-utils.h"
 #include "fr-command.h"
 #include "fr-command-tar.h"
 
+#define ACTIVITY_DELAY 20
+
 static void fr_command_tar_class_init  (FRCommandTarClass *class);
 static void fr_command_tar_init        (FRCommand         *afile);
 static void fr_command_tar_finalize    (GObject           *object);
@@ -126,6 +129,7 @@ process_line (char     *line,
 	char       **fields;
 	int          date_idx;
 	char        *field_date, *field_time, *field_size, *field_name;
+	char        *name;
 
 	g_return_if_fail (line != NULL);
 
@@ -134,7 +138,7 @@ process_line (char     *line,
 	date_idx = file_list__get_index_from_pattern (line, "%n%n%n%n-%n%n-%n%n %n%n:%n%n");
 
 	field_size = file_list__get_prev_field (line, date_idx, 1);
-	fdata->size = atoll (field_size);
+	fdata->size = g_ascii_strtoull (field_size, NULL, 10);
 	g_free (field_size);
 
 	field_date = file_list__get_next_field (line, date_idx, 1);
@@ -153,13 +157,15 @@ process_line (char     *line,
 		fields = g_strsplit (field_name, " link to ", 2);
 	}
 
-	if (*(fields[0]) == '/') {
-		fdata->full_path = g_strdup (fields[0]);
+	name = unescape_str (fields[0]);
+	if (*name == '/') {
+		fdata->full_path = g_strdup (name);
 		fdata->original_path = fdata->full_path;
 	} else {
-		fdata->full_path = g_strconcat ("/", fields[0], NULL);
+		fdata->full_path = g_strconcat ("/", name, NULL);
 		fdata->original_path = fdata->full_path + 1;
 	}
+	g_free (name);
 
 	if (fields[1] != NULL)
 		fdata->link = g_strdup (fields[1]);
@@ -253,9 +259,9 @@ static void
 process_line__generic (char     *line, 
 		       gpointer  data,
 		       char     *action_msg)
-{
-	FRCommand  *comm = FR_COMMAND (data);
-	char       *msg;
+{	
+	FRCommand *comm = FR_COMMAND (data);
+	char      *msg;
 
 	if (line == NULL)
 		return;
@@ -263,12 +269,14 @@ process_line__generic (char     *line,
 	if (line[strlen (line) - 1] == '/') /* ignore directories */
 		return;
 
-	msg = g_strconcat (action_msg, line, NULL);
+	comm->n_file++;
+
+	msg = g_strconcat (action_msg, file_name_from_path (line), NULL);
 	fr_command_message (comm, msg);
 	g_free (msg);
 
 	if (comm->n_files != 0) {
-		double fraction = (double) comm->n_file++ / comm->n_files;
+		double fraction = (double) comm->n_file / (comm->n_files+1);
 		fr_command_progress (comm, fraction);
 	}
 }
@@ -743,26 +751,22 @@ fr_command_tar_uncompress (FRCommand *comm)
 }
 
 
-char *
+static char *
 fr_command_tar_escape (FRCommand     *comm,
 		       const char    *str)
 {
 	char *estr;
 	char *estr2;
+	char *estr3;
+
+        estr = escape_str (str, "\\");
+        estr2 = escape_str (estr, "\\$?*'& !|()@#:;");
+        estr3 = escape_str_common (estr2, "[]", '[', ']');
 
-        estr = escape_str (str, "$?*\\'& !|()@#:;");
-        estr2 = escape_str_common (estr, "[]", '[', ']');
 	g_free (estr);
+	g_free (estr2);
 
-	/*
-	  if ((strcmp (estr2, str) != 0) || strchrs (str, "& !()|@#:;")) {
-	  char *estr3 = g_strconcat ("'", estr2, "'", NULL);
-	  g_free (estr2);
-	  estr2 = estr3;
-	  }
-	*/
-
-	return estr2;
+	return estr3;
 }
 
 
@@ -792,6 +796,10 @@ fr_command_tar_class_init (FRCommandTarClass *class)
 static void 
 fr_command_tar_init (FRCommand *comm)
 {
+	FRCommandTar *comm_tar = (FRCommandTar*) comm;
+
+	comm->file_type = FR_FILE_TYPE_TAR;
+
 	comm->propCanModify                = TRUE;
 	comm->propAddCanUpdate             = TRUE;
 	comm->propAddCanReplace            = FALSE; 
@@ -800,6 +808,8 @@ fr_command_tar_init (FRCommand *comm)
 	comm->propExtractCanJunkPaths      = FALSE;
 	comm->propPassword                 = FALSE;
 	comm->propTest                     = FALSE;
+
+	comm_tar->msg = NULL;
 }
 
 
@@ -818,6 +828,11 @@ fr_command_tar_finalize (GObject *object)
 		comm_tar->uncomp_filename = NULL;
 	}
 
+	if (comm_tar->msg != NULL) {
+		g_free (comm_tar->msg);
+		comm_tar->msg = NULL;
+	}
+
 	/* Chain up */
         if (G_OBJECT_CLASS (parent_class)->finalize)
 		G_OBJECT_CLASS (parent_class)->finalize (object);
