@@ -126,7 +126,7 @@ process_line (char     *line,
 		if (ssize[0] == '\0')
 			size = 0;
 		else
-			size = atoi (ssize);
+			size = g_ascii_strtoull (ssize, NULL, 10);
 
 		if (comm->file_list != NULL) {
 			fdata = (FileData *) comm->file_list->data;
@@ -288,6 +288,8 @@ fr_command_unstuff_class_init (FRCommandUnstuffClass *class)
 static void 
 fr_command_unstuff_init (FRCommand *comm)
 {
+	comm->file_type = FR_FILE_TYPE_STUFFIT;
+
 	comm->propCanModify                = FALSE;
 	comm->propAddCanUpdate             = FALSE;
 	comm->propAddCanReplace            = FALSE;
@@ -351,6 +353,10 @@ fr_command_unstuff_new (FRProcess  *process,
 {
 	FRCommand *comm;
 
+	if (!is_program_in_path("unstuff")) {
+		return NULL;
+	}
+
 	comm = FR_COMMAND (g_object_new (FR_TYPE_COMMAND_UNSTUFF, NULL));
 	fr_command_construct (comm, process, filename);
 
