@@ -38,32 +38,36 @@ typedef struct _FRCommand       FRCommand;
 typedef struct _FRCommandClass  FRCommandClass;
 
 typedef enum {
+	FR_ACTION_NONE,
 	FR_ACTION_LIST,
 	FR_ACTION_ADD,
 	FR_ACTION_DELETE,
 	FR_ACTION_EXTRACT,
 	FR_ACTION_TEST,
-	FR_ACTION_GET_LIST
+	FR_ACTION_GET_LIST,
+	FR_ACTION_SAVE
 } FRAction;
 
 struct _FRCommand
 {
         GObject  __parent;
 
-	GList * file_list;       /* FileData elements */
+	FRFileType  file_type;
+	GList      *file_list;       /* FileData elements */
 
 	/*<protected>*/
 
 	/* properties the command supports. */
 
-	uint propCanModify : 1;
-	uint propAddCanUpdate : 1;
-	uint propAddCanReplace : 1;
-	uint propExtractCanAvoidOverwrite : 1;
-	uint propExtractCanSkipOlder : 1;
-	uint propExtractCanJunkPaths : 1;
-	uint propPassword : 1;
-	uint propTest : 1;
+	guint propCanModify : 1;
+	guint propAddCanUpdate : 1;
+	guint propAddCanReplace : 1;
+	guint propExtractCanAvoidOverwrite : 1;
+	guint propExtractCanSkipOlder : 1;
+	guint propExtractCanJunkPaths : 1;
+	guint propPassword : 1;
+	guint propTest : 1;
+	guint propCanExtractAll : 1;
 
 	/* used by the progress signal */
 
@@ -119,6 +123,8 @@ struct _FRCommandClass
 	void        (*handle_error)   (FRCommand     *comm,
 				       FRProcError   *error);
 
+	char *      (*escape)         (FRCommand     *comm,
+				       const char    *str);
 
 	/*<signals>*/
 
@@ -173,6 +179,9 @@ void           fr_command_uncompress         (FRCommand     *comm);
 void           fr_command_recompress         (FRCommand     *comm,
 					      FRCompression  compression);
 
+char *         fr_command_escape             (FRCommand     *comm,
+					      const char    *str);
+
 /* protected functions */
 
 void           fr_command_progress           (FRCommand     *comm,
